@@ -32,9 +32,10 @@ public:
 
 protected:
     void draw(QPainter *painter);
+    void drawTriggerIndicator(QPainter *painter);
 
 private:
-    void drawBackground();
+    void prepareBackground();
 
 };
 
