@@ -22,6 +22,7 @@
 
 #include "pa_utils.h"
 
+#include <QDate>
 #include <QLineEdit>
 #include <QSettings>
 #include <QString>
@@ -259,6 +260,7 @@ void MainWindow::updateValues(float value){
     if(loggingEnabled){
         QTextStream out(logFile);
         out << logIndex << ";"
+                << QDate::currentDate().toString("yyyy-MM-dd") << ";"
                 << QTime::currentTime().toString("hh:mm:ss.zzz") << ";"
                 << vol << ";"
                 << ((ui->radioButtonDb->isChecked()) ? "dB" : "Linear") << "\n";
