@@ -36,10 +36,11 @@ public:
 
 protected:
     void draw(QPainter *painter);
+    void drawTriggerIndicator(QPainter *painter);
     void resizeEvent(QResizeEvent *event);
 
 private:
-    void drawBackground();
+    void prepareBackground();
     void initValues();
 
     QList<float> *volumeValues;
